<template>
  <a-spin :spinning='load'>
    <a-card :bordered='false'>
      <div>
        <a-table
          ref='table'
          :columns='columns'
          :customRow='clickThenSelect'
          :dataSource='dataSource'
          :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
          bordered
          class='j-table-force-nowrap'
          rowKey='name'
          size='middle'
          :pagination=false
          style='height: 400px; overflow-y: auto;'
        >
        </a-table>
      </div>
    </a-card>
  </a-spin>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { getAction } from '@/api/manage'

export default {
  name: 'FunctionInformation',
  mixins: [JeecgListMixin],
  components: {
    JDictSelectTag,
    JInput,
    JEllipsis
  },
  created() {
  },
  data() {
    return {
      columns: [
        {
          title: '',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '名称',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '描述',
          align: 'center',
          dataIndex: 'describe'
        },
        {
          title: '声明',
          align: 'center',
          dataIndex: 'state'
        },
        {
          title: '数据类型',
          align: 'center',
          dataIndex: 'dataType'
        },
        {
          title: '变量',
          align: 'center',
          dataIndex: 'tag'
        }
      ],
      load: false,
      url: {
        list: '/empty/parameter/function'
      }
    }
  },
  methods: {
    // 查询终端列表
    loadData(arg) {
      if (arg === undefined){
        arg = 'Convert'
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      params.functionType = arg
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.result) {
          this.dataSource = res.result
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })

    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.name.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      this.selectedRowKeys = selectedRowKeys
      // 调用父组件方法存储参数
      this.$emit('ok', selectionRows)
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    searchQuery() {
      this.loadData()
      this.onClearSelected()
    },
    searchReset() {
      this.queryParam = {}
      this.loadData()
      this.onClearSelected()
    },
    handleEdit(record) {
      this.$refs.modalForm.edit(record)
      this.$refs.modalForm.title = '编辑'
      this.$refs.modalForm.disableSubmit = false
    }
  }
}
</script>
<style scoped>
.ant-table-row {
  height: 50px;
}
</style>
